@@ -18,6 +18,14 @@ INDENT = "   "
 HEADERS = ["=", "-", '"', "'", "~"]
 
 
+def get_col_widths(dataframe, padding=4):
+    # Then, we concatenate this to the max of the lengths of column name and its values for each column, left to right
+    return [
+        max([len(str(s)) for s in dataframe[col].values] + [len(col)]) + padding
+        for col in dataframe.columns
+    ]
+
+
 # =============================================================================
 # a few RST helpers
 # =============================================================================
@@ -496,7 +504,8 @@ table.docutils th {
                     fh.write(_write(".. glossary::\n\n"))
                     columns = {k: v["items"] for k, v in schema.columns_specs.items()}
                     for colname, colspecs in columns.items():
-                        bookmark = f".. _field_{tab}-{colname}:\n"
+                        _colname = colname.replace("::", "_")
+                        bookmark = f".. _field_{tab}-{_colname}:\n"
                         fh.write(bookmark)
                         col_status = field_status(colname, schema)
                         # add label
@@ -727,6 +736,9 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
                 for typ in colspecs[colname]["items"].get("anyOf", []):
                     types.add(typ["type"])
                 types.discard(None)
+                if "null" in types:
+                    types.remove("null")
+                    types = ["Empty"] + list(types)
                 types_str = ", ".join(types)
                 comment = f"Type(s): {types_str}"
                 if colspecs[colname]["uniqueItems"]:
@@ -740,13 +752,17 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
                         comment += f'\ndefault: "{default}"'
                     else:
                         comment += f"\ndefault: {default}"
+                if enum := colspecs[colname]["items"].get("enum"):
+                    comment += f"\nOne value of {enum}"
                 worksheet.write_comment(
                     cell_header,
                     comment,
                     {
                         "author": "numeric-GmbH",
-                        "color": "#ad7fa8",
+                        "color": "#b3ceeb",
                         "visible": False,
+                        "x_scale": 2,
+                        "font_size": 10,
                     },
                 )
             if ws_has_units:
@@ -756,6 +772,8 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
                 worksheet.freeze_panes(1, 1)
             # -----------------------------------------------------------------
             # autofit
+            for i, width in enumerate(get_col_widths(df)):
+                worksheet.set_column(i, i, width)
     logging.info(f"finilized {output}")
     return output, cols
 
