@@ -851,13 +851,18 @@ class ValidatorMixin:
         """return user-friendly row index"""
         if not row_reporting_offset:
             return ix
-        reported_rownb = self._data[tabname].loc[ix]["__rownb_xlsx"]
-        if row_reporting_offset == "data":
-            is_units = len(self.getunits(tabname)) > 0
-            if is_units:
-                reported_rownb -= 2
-            else:
-                reported_rownb -= 1
+        try:
+            reported_rownb = self._data[tabname].loc[ix]["__rownb_xlsx"]
+        except KeyError:
+            # no `__rownb_xlsx` field
+            reported_rownb = "?"
+        else:
+            if row_reporting_offset == "data":
+                is_units = len(self.getunits(tabname)) > 0
+                if is_units:
+                    reported_rownb -= 2
+                else:
+                    reported_rownb -= 1
         return reported_rownb
 
     def dump_template(self):
